Grease = LibStub("AceAddon-3.0"):NewAddon("Grease", "AceConsole-3.0")

local AceConfigDialog = LibStub("AceConfigDialog-3.0")

local defaults = {
	profile = {
		WHISPER = false,
		CHANNEL = false,
		SAY = true,
		YELL = false,
		PARTY = true,
		RAID = true,
		INSTANCE_CHAT = true,
		GUILD = true,
		OFFICER = true,
		BN_WHISPER = false,
		BN_CONVERSATION = false,
	}
}


function Grease:SetSticky(chattype, sticky)
	if sticky == true then
		ChatTypeInfo[chattype].sticky = 1
	elseif sticky == false then
		ChatTypeInfo[chattype].sticky = 0
	end
end

local options = {
	name = "Grease",
	handler = Grease,
	type = 'group',
	args = {
		WHISPER = {
			type = "toggle",
			name = "Whisper",
			desc = "Whispers sent to another player. Does not include RealID.",
			get = function() return Grease.db.profile.WHISPER end,
			set = function(info, v)
					Grease.db.profile.WHISPER = v
					Grease:SetSticky("WHISPER", Grease.db.profile.WHISPER)
				end,
			order = 1,
		},

		CHANNEL = {
			type = "toggle",
			name = "Channel",
			desc = "All channels numbered 1-10",
			get = function() return Grease.db.profile.CHANNEL end,
			set = function(info, v)
					Grease.db.profile.CHANNEL = v
					Grease:SetSticky("CHANNEL", Grease.db.profile.CHANNEL)
				end,
			order = 2,
		},

		SAY = {
			type = "toggle",
			name = "Say",
			desc = "White chat used with /s",
			get = function() return Grease.db.profile.SAY end,
			set = function(info, v)
					Grease.db.profile.SAY = v
					Grease:SetSticky("SAY", Grease.db.profile.SAY)
				end,
			order = 3,
		},

		YELL = {
			type = "toggle",
			name = "Yell",
			desc = "Red chat used with /y",
			get = function() return Grease.db.profile.YELL end,
			set = function(info, v)
					Grease.db.profile.YELL = v
					Grease:SetSticky("YELL", Grease.db.profile.YELL)
				end,
			order = 4,
		},

		PARTY = {
			type = "toggle",
			name = "Party",
			desc = "Blue chat used in party with /p",
			get = function() return Grease.db.profile.PARTY end,
			set = function(info, v)
					Grease.db.profile.PARTY = v
					Grease:SetSticky("PARTY", Grease.db.profile.PARTY)
				end,
			order = 5,
		},

		RAID = {
			type = "toggle",
			name = "Raid",
			desc = "Used in raid with /ra",
			get = function() return Grease.db.profile.RAID end,
			set = function(info, v)
					Grease.db.profile.RAID = v
					Grease:SetSticky("RAID", Grease.db.profile.RAID)
				end,
			order = 6,
		},

		INSTANCE_CHAT = {
			type = "toggle",
			name = "Instance",
			desc = "The instance channel added in 5.1 (/i)",
			get = function() return Grease.db.profile.INSTANCE_CHAT end,
			set = function(info, v)
					Grease.db.profile.INSTANCE_CHAT = v
					Grease:SetSticky("INSTANCE_CHAT", Grease.db.profile.INSTANCE_CHAT)
				end,
			order = 7,
		},

		GUILD = {
			type = "toggle",
			name = "Guild",
			desc = "Guild chat used with /g",
			get = function() return Grease.db.profile.GUILD end,
			set = function(info, v)
					Grease.db.profile.GUILD = v
					Grease:SetSticky("GUILD", Grease.db.profile.GUILD)
				end,
			order = 8,
		},

		OFFICER = {
			type = "toggle",
			name = "Officer",
			desc = "Guild Officer chat used with /o",
			get = function() return Grease.db.profile.OFFICER end,
			set = function(info, v)
					Grease.db.profile.OFFICER = v
					Grease:SetSticky("OFFICER", Grease.db.profile.OFFICER)
				end,
			order = 9,
		},
		
		BN_WHISPER = {
			type = "toggle",
			name = "RealID Whisper",
			desc = "Blue whispers sent from a RealID friend. (Does this even have a slash command?)",
			get = function() return Grease.db.profile.BN_WHISPER end,
			set = function(info, v)
					Grease.db.profile.BN_WHISPER = v
					Grease:SetSticky("BN_WHISPER", Grease.db.profile.BN_WHISPER)
				end,
			order = 10,
		},
		
		BN_CONVERSATION = {
			type = "toggle",
			name = "RealID Conversation",
			desc = "RealID conversations with two or more people, starting at /11.",
			get = function() return Grease.db.profile.BN_CONVERSATION end,
			set = function (info, v)
					Grease.db.profile.BN_CONVERSATION = v
					Grease:SetSticky("BN_CONVERSATION", Grease.db.profile.BN_CONVERSATION)
				end,
			order = 11,
		},
	},
}

function Grease:slashies()
	if not command or command:trim() == "" then
		InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
	else
		InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
	end
end

function Grease:OnInitialize()
--	self:Print("Grease initialized.")
	self.db = LibStub("AceDB-3.0"):New("GreaseDB", defaults)
	self:RegisterChatCommand("grease", "slashies")
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Grease", "Grease")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("Grease", options)
end

function Grease:OnEnable()
--	self:Print("Grease loaded.")
	self:SetSticky("WHISPER", Grease.db.profile.WHISPER)
	self:SetSticky("CHANNEL", Grease.db.profile.CHANNEL)
	self:SetSticky("SAY", Grease.db.profile.SAY)
	self:SetSticky("YELL", Grease.db.profile.YELL)
	self:SetSticky("PARTY", Grease.db.profile.PARTY)
	self:SetSticky("RAID", Grease.db.profile.RAID)
	self:SetSticky("INSTANCE_CHAT", Grease.db.profile.INSTANCE_CHAT)
	self:SetSticky("GUILD", Grease.db.profile.GUILD)
	self:SetSticky("OFFICER", Grease.db.profile.OFFICER)
	self:SetSticky("BN_WHISPER", Grease.db.profile.BN_WHISPER)
	self:SetSticky("BN_CONVERSATION", Grease.db.profile.BN_CONVERSATION)
end

function Grease:OnDisable()
--	self:Print("Grease disabled.")
end

